load_from_file

Function load_from_file 

pub fn load_from_file(path: &str) -> Result<SerializedModel, Error>
Load a serialized model from a file.

This validates the format version but does not validate the model type. Type validation happens when converting to a specific model type.

Arguments

  • path - File path to read from

Returns

Returns the SerializedModel on success, or an Error if reading fails.